<?php

namespace App\Http\Controllers;

use App\Models\Wishlist;
use Illuminate\Http\Request;

class WishlistController extends Controller
{
    public function addToWishlist(Request $request)
    {
        $request->validate([
            'product_id' => 'required|exists:products,id',
        ]);

        $existingWishlistItem = Wishlist::where('user_id', $request->user()->id)
            ->where('product_id', $request->product_id)
            ->first();

        if ($existingWishlistItem) {
            return response()->json(['success' => false, 'message' => 'Product already in your  wishlist.', 'data' => []]);
        }

        Wishlist::create([
            'user_id' => $request->user()->id,
            'product_id' => $request->product_id,
        ]);

        return response()->json(['success' => true, 'message' => 'Product added to wishlist successfully.', 'data' => []], 201);
    }
    
    public function getUserWishlist()
    {
        $wishlistProducts = Wishlist::with('product.brand')->with('product.images')->where('user_id', request()->user()->id)->get();
        return response()->json(['success' => true, 'message' => 'user wishlist products', 'data' => $wishlistProducts]);;
    }
    
     public function deleteWishlist($id)
    {
        $wishlistItem = Wishlist::where('user_id', request()->user()->id)
            ->where('product_id', $id)
            ->first();

        // Check if the item exists
        if (!$wishlistItem) {
            return response()->json([
                'success' => false,
                'message' => 'Wishlist item not found',
                'data' => []
            ], 404);
        }

        // Delete the wishlist item
        $wishlistItem->delete();

        return response()->json([
            'success' => true,
            'message' => 'Wishlist item deleted successfully',
            'data' => []
        ]);
    }
}
