<?php

use App\Http\Controllers\BrandsController;
use App\Http\Controllers\CampaignController;
use App\Http\Controllers\CartController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\ProductController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\UserController;
use App\Http\Controllers\WishlistController;
use App\Http\Controllers\ContactController;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "api" middleware group. Make something great!
|
*/

Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    return $request->user();
});

Route::prefix('auth')->controller(UserController::class)->group(function () {
    Route::post('/signup', 'signup');
    Route::post('/login', 'login');
    Route::post('/change-password', 'changePassword')->middleware('auth:sanctum');
    Route::post('/forgot-password', 'forgotPassword');
    Route::post('verify-code', 'verifyOtpPassword');
    Route::post('update-password', 'updatePassword');
});



Route::prefix('brands')->controller(BrandsController::class)->group(function () {
    Route::get('/', 'brands');
});


Route::prefix('categories')->controller(CategoryController::class)->group(function () {
    Route::get('/', 'categories');
    Route::get('/brand/{id}', 'brandCategories');
    Route::get('/{id}/products', 'categoryProducts');
});


Route::prefix('home')->controller(HomeController::class)->group(function () {
    Route::get('/', 'homeScreenAPI');
});

Route::prefix('campaigns-products')->controller(CampaignController::class)->group(function () {
    Route::get('/{brand_id}/{category_id}', 'campaignProducts');
});

Route::prefix('products')->controller(ProductController::class)->group(function () {
    Route::get('/details/{id}', 'productsDetails');
    Route::get('/search', 'searchProducts');
});

Route::prefix('user')->middleware('auth:sanctum')->controller(UserController::class)->group(function () {
    Route::get('/profile', 'getUserProfile');
    Route::put('update-profile', 'updateProfile');
});

Route::prefix('user/wishlist')->middleware('auth:sanctum')->controller(WishlistController::class)->group(function () {
    Route::post('/add', 'addToWishlist');
    Route::get('/', 'getUserWishlist');
    Route::delete('/delete/{id}', 'deleteWishlist');
});


Route::prefix('cart')->middleware('auth:sanctum')->controller(CartController::class)->group(function () {
    Route::post('add-to-cart', 'addToCart');
    Route::get('get-user-cart', 'getUserCart');
    Route::delete('/delete/{id}', 'deleteUserCart');
    Route::post('checkout', 'checkout');
});

Route::post('/contact', [ContactController::class, 'sendContactEmail']);

